Reference/API
-------------
.. automodapi:: paintbox.sed
   :no-inheritance-diagram:

.. automodapi:: paintbox.extlaws
   :no-inheritance-diagram:

.. automodapi:: paintbox.likelihoods
   :no-inheritance-diagram:

.. automodapi:: paintbox.operators
   :no-inheritance-diagram:

